;; Generated package description from wcheck-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "wcheck-mode" "2026.0.20260425.170346" "General interface for text checkers" 'nil :commit "d9cea40a86751e646bfeb06826454c94e18bb2d7" :authors '(("Teemu Likonen" . "tlikonen@iki.fi")) :maintainer '("Teemu Likonen" . "tlikonen@iki.fi") :keywords '("text" "spell" "check" "languages" "ispell") :url "https://github.com/tlikonen/wcheck-mode")
